==> haskell-wai-extra-3.0.22.0-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.22.0
id: wai-extra-3.0.22.0-K8NG3qWUot12wYOZjPCu7Q
key: wai-extra-3.0.22.0-K8NG3qWUot12wYOZjPCu7Q
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: 4ef0a513a3847e87fe2cab4e6369c095
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-extra-3.0.22.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-extra-3.0.22.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-extra-3.0.22.0
hs-libraries: HSwai-extra-3.0.22.0-K8NG3qWUot12wYOZjPCu7Q
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-L2G3elceofc1yhjOKmecqb
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 time-1.8.0.2
    network-2.6.3.4-4K065be0R6PJVLRtkEGbjz directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    http-types-0.9.1-6X2WIr2ON586RGGZSRTan8
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    fast-logger-2.4.11-1HiILbjmDI144DyL3lstwr
    wai-logger-2.3.2-J6YdmqjRCxlCk2CKFjZIRA
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe containers-0.5.10.2
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6 deepseq-1.4.3.0
    streaming-commons-0.1.19-Bamp4xnZWFNABGCJoIZ3bj
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    cookie-0.4.4-EyDWAwF5tw7bEHLWBuq76
    vault-0.3.1.0-DHSp43iF1X5Dn5mzJtu2w7
    zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    iproute-1.7.3-5ay907LP7XW9ophjOhDuvR unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             wai-3.2.1.2-L2G3elceofc1yhjOKmecqb=01d341254f1cf59b77299ea88d31ec1e
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             network-2.6.3.4-4K065be0R6PJVLRtkEGbjz=20387964172162461d5c295001ad0241
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             http-types-0.9.1-6X2WIr2ON586RGGZSRTan8=f3cf44f811b734b379910c70c68230da
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=b9d2385c579e775ca271e0b2d301ad48
             fast-logger-2.4.11-1HiILbjmDI144DyL3lstwr=1a9fdf0f715cf565fa37221051d7343f
             wai-logger-2.3.2-J6YdmqjRCxlCk2CKFjZIRA=79e48b1fa2cac8e6d805f37072601e73
             ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=2129d94dd9a574dcd2d2bc46dca144d6
             stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe=ad8df4d60dd590f7c73e1ab245c06a55
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM=cc4a142431ce6690ee33d53324633160
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=69f8e20d56d646f8c21a0cacb2949476
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             streaming-commons-0.1.19-Bamp4xnZWFNABGCJoIZ3bj=117db729dfc7014e4bf6a0861c604bd6
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             cookie-0.4.4-EyDWAwF5tw7bEHLWBuq76=b9dea7f40a09ac7e7fbb3a4ecc313d23
             vault-0.3.1.0-DHSp43iF1X5Dn5mzJtu2w7=512aa0988128f7010f2af620d93b0135
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=0435506582323b785ad7538064910d9e
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             iproute-1.7.3-5ay907LP7XW9ophjOhDuvR=9fb601fc395d13debe8270fbc131bd6d
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.22.0-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.22.0
id: wai-extra-3.0.22.0-E2USIt4Shvk4ascor7S2xG
key: wai-extra-3.0.22.0-E2USIt4Shvk4ascor7S2xG
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: fa3686fd291da7391dd1cc002640bd47
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-extra-3.0.22.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-extra-3.0.22.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-extra-3.0.22.0
hs-libraries: HSwai-extra-3.0.22.0-E2USIt4Shvk4ascor7S2xG
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 time-1.8.0.2
    network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    http-types-0.9.1-6X2WIr2ON586RGGZSRTan8
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    fast-logger-2.4.11-1HiILbjmDI144DyL3lstwr
    wai-logger-2.3.2-1nDYZOZIKD0hRiBS5yYvr
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe containers-0.5.10.2
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6 deepseq-1.4.3.0
    streaming-commons-0.1.19-Zc0nVsMOstJGP6TUIkcb8
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    cookie-0.4.4-EyDWAwF5tw7bEHLWBuq76
    vault-0.3.1.0-DHSp43iF1X5Dn5mzJtu2w7
    zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    iproute-1.7.3-9s2Ivt4lS3ACuYGcqY1jFv unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             wai-3.2.1.2-DsLSlUMPljoENiFUuH3YiB=591867d961152e6769889f7aae419d50
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp=e81ab755128c48e8082525402fc065c2
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             http-types-0.9.1-6X2WIr2ON586RGGZSRTan8=f3cf44f811b734b379910c70c68230da
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=b9d2385c579e775ca271e0b2d301ad48
             fast-logger-2.4.11-1HiILbjmDI144DyL3lstwr=1a9fdf0f715cf565fa37221051d7343f
             wai-logger-2.3.2-1nDYZOZIKD0hRiBS5yYvr=0809f69813cf4aaaefaa2e7cd39b4a87
             ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=2129d94dd9a574dcd2d2bc46dca144d6
             stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe=ad8df4d60dd590f7c73e1ab245c06a55
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             word8-0.1.3-C7vr3ObxpJ0EFhIkA3lNrM=cc4a142431ce6690ee33d53324633160
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=69f8e20d56d646f8c21a0cacb2949476
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             streaming-commons-0.1.19-Zc0nVsMOstJGP6TUIkcb8=d5b92cc4692073839eaee565bf3f3b23
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             cookie-0.4.4-EyDWAwF5tw7bEHLWBuq76=b9dea7f40a09ac7e7fbb3a4ecc313d23
             vault-0.3.1.0-DHSp43iF1X5Dn5mzJtu2w7=512aa0988128f7010f2af620d93b0135
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=0435506582323b785ad7538064910d9e
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             iproute-1.7.3-9s2Ivt4lS3ACuYGcqY1jFv=bff2a3fd7ec12fcda7ac306d0dead1df
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
